@@ -71,6 +71,12 @@
 
 #include <QtGui/qpainter.h>
 
+#include <QtNetwork/QNetworkSession>
+
+#include <QtNetwork/QNetworkAccessManager>
+
+#include <QtNetwork/QNetworkInterface>
+
 #include "gconfitem.h"
 
 class ProxySwitcher : public QWidget
@@ -129,7 +135,11 @@ public:
 	QString GCONF_KEY_PROXY_FTP_HOST;
 	QString GCONF_KEY_PROXY_RTSP_PORT;
 	QString GCONF_KEY_PROXY_RTSP_HOST;
-	
+
+	QNetworkSession *ns;
+	QNetworkAccessManager *am;
+	QNetworkInterface	ni;
+
 	QPixmap button[2];
         QPixmap proxyButton[3];
 	int buttonState;
@@ -152,8 +162,13 @@ public:
 	GCONF_KEY_LAST_USED = GCONF_KEY_DIR_CON + "/last_used_network";
 	lastUsed = new GConfItem(GCONF_KEY_LAST_USED,this);
 	lastUsedNetworkName = lastUsed->value();
+	am = new QNetworkAccessManager(this);
+
+	ns = new QNetworkSession(am->activeConfiguration(),this);
 	
-	
+	ni = ns->interface();
+
+	qDebug()<<ni.name();
 
 	//calls the the method to set up all the gconf keys to the correct values
 	setupGConfKeys();
